# IMAPY

Python library to perform Inner Metric Analysis [1] on a series on onsets.

pypi link: https://pypi.org/project/IMAPY-music/

Originally coded in Java by Chris Dyer (and in C++ by Peter van Kranenburg).

[1] Nestke, A. and Noll, T. (2001). Inner Metric Analysis. In Haluska, J. (ed.), Music and Mathematics, pp. 91–111. Bratislava: Tatra Mountains Publications.

[![Python package](https://github.com/NadiaCarvalho/IMAPY/actions/workflows/python-package.yml/badge.svg)](https://github.com/NadiaCarvalho/IMAPY/actions/workflows/python-package.yml)
